# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2025-03-19

### Added

- Add PerfMsTracker from flask-matomo2 by [@kod-kristoff](https://github.com/kod-kristoff)
- Add constants by [@kod-kristoff](https://github.com/kod-kristoff)

### Documentation

- Initially docs by [@kod-kristoff](https://github.com/kod-kristoff)

### New Contributors
* @kod-kristoff made their first contribution in [#1](https://github.com/spraakbanken/matomo-core/pull/1)
<!-- generated by git-cliff -->
